import { Plugin } from 'esbuild';

interface CSSPluginOptions {
    /**
     * By default name is generated without hash so that it is easier and reliable for library users to override some CSS.
     * Refer [loader-utils docs](https://github.com/webpack/loader-utils?tab=readme-ov-file#interpolatename) for more options
     * @defaultValue A function that generates name similar to [name]__[local] but without .module
     */
    generateScopedName?: string | ((className: string, path: string, css: string) => string);
    /** set skipAutoPrefixer to true to disable autoprefixer */
    skipAutoPrefixer?: boolean;
    /** global CSS class prefix. @defaultValue undefined */
    globalPrefix?: string;
    /** If you want to keep .module.css files. @defaultValue undefined */
    keepModules?: boolean;
}
declare const cssPlugin: (options?: CSSPluginOptions) => Plugin;

export { cssPlugin as default };
